pub enum Lifecycle {
ApprovalRequested,
Approved {
decided_by: ActorRef,
decided_at: DateTime<Utc>,
},
Rejected {
decided_by: ActorRef,
decided_at: DateTime<Utc>,
},
Cancelled,
Superseded,
}Expand description
Approval lifecycle state for draft, requested, approved, rejected, or non-applicable review gates.
Variants
ApprovalRequested
Approval requested state or source category preserved for normalized resort records.
Approved
Approved state or source category preserved for normalized resort records.
Fields
Rejected
Rejected state or source category preserved for normalized resort records.
Fields
Cancelled
Reservation is no longer active.
Superseded
Superseded state or source category preserved for normalized resort records.
Implementations